/* BDF - Copyright (c) 2018-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.multi.jsonproducers;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.json.SubsetTreeJson;
import fr.exemole.bdfserver.multi.Multi;
import java.io.IOException;
import java.util.SortedSet;
import net.fichotheque.Fichotheque;
import net.fichotheque.SubsetKey;
import net.fichotheque.utils.FichothequeMetadataUtils;
import net.mapeadores.util.json.JSONWriter;


/**
 *
 * @author Vincent Calame
 */
public class FichothequeArrayJsonProducer extends MultiJsonProducer {

    public FichothequeArrayJsonProducer(Multi multi) {
        super(multi, true);
    }

    @Override
    public void mainProperties(JSONWriter jw) throws IOException {
        SortedSet<String> set = multi.getExistingNameSet();
        jw.key("fichothequeArray");
        jw.array();
        for (String name : set) {
            boolean isInit = multi.isInit(name);
            jw.object();
            {
                jw.key("name")
                        .value(name);
                jw.key("init")
                        .value(isInit);
                if (isInit) {
                    fichothequeProperties(jw, multi.getBdfServer(name));
                }
            }
            jw.endObject();
        }
        jw.endArray();
    }

    private void fichothequeProperties(JSONWriter jw, BdfServer bdfServer) throws IOException {
        Fichotheque fichotheque = bdfServer.getFichotheque();
        jw.key("title")
                .value(FichothequeMetadataUtils.getTitle(fichotheque, lang));
        jw.key("longtitle")
                .value(FichothequeMetadataUtils.getLongTitle(fichotheque, lang));
        SubsetTreeJson.Parameters parameters = new SubsetTreeJson.Parameters(bdfServer, lang, messageLocalisation);
        SubsetTreeJson.properties(jw, parameters, SubsetKey.CATEGORY_CORPUS);
        SubsetTreeJson.properties(jw, parameters, SubsetKey.CATEGORY_THESAURUS);
        SubsetTreeJson.properties(jw, parameters, SubsetKey.CATEGORY_SPHERE);
        SubsetTreeJson.properties(jw, parameters, SubsetKey.CATEGORY_ALBUM);
        SubsetTreeJson.properties(jw, parameters, SubsetKey.CATEGORY_ADDENDA);
    }

}
