/* BdfServer - Copyright (c) 2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.exportation.transformation.compilers;

import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;


/**
 *
 * @author Vincent Calame
 */
class PropertiesOdParser {

    private final static String TAG_END = "</text:text-input>";
    private final String content;
    private int currentStart = 0;
    private StringBuilder buf = new StringBuilder();
    private List<Object> partList = new ArrayList<Object>();

    PropertiesOdParser(String content) {
        this.content = content;
    }

    private boolean next() {
        int inputTagStartIndex = content.indexOf("<text:text-input", currentStart);
        if (inputTagStartIndex == -1) {
            partList.add(content.substring(currentStart));
            return false;
        }
        if (inputTagStartIndex > currentStart) {
            partList.add(content.substring(currentStart, inputTagStartIndex));
        }
        int inputContentStartIndex = content.indexOf(">", inputTagStartIndex) + 1;
        if (content.charAt(inputContentStartIndex - 2) == '/') {
            currentStart = inputContentStartIndex;
            return true;
        }
        int inputContentEndIndex = content.indexOf(TAG_END, inputContentStartIndex);
        String propertyText = content.substring(inputContentStartIndex, inputContentEndIndex).trim();
        String propertyName = propertyText;
        partList.add(new PropertyPart(propertyName));
        currentStart = inputContentEndIndex + TAG_END.length();
        return true;
    }

    static List<Object> parse(String content) throws ParseException {
        PropertiesOdParser parser = new PropertiesOdParser(content);
        while (true) {
            if (!parser.next()) {
                break;
            }
        }
        return parser.partList;
    }

}
