/* BdfServer_Commands - Copyright (c) 2015-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.addenda;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import fr.exemole.bdfserver.tools.instruction.PermissionChecker;
import java.text.ParseException;
import net.fichotheque.ExistingNameException;
import net.fichotheque.addenda.AddendaEditor;
import net.fichotheque.addenda.Document;
import net.fichotheque.utils.AddendaUtils;
import net.mapeadores.util.exceptions.ShouldNotOccurException;
import net.mapeadores.util.request.RequestMap;
import net.mapeadores.util.text.StringUtils;


/**
 *
 * @author Vincent Calame
 */
public class DocumentNameChangeCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "DocumentNameChange";
    public final static String COMMANDKEY = "_ ADD-05";
    public final static String NAME_PARAMNAME = "documentname";
    private Document document;
    private String newDocumentName;

    public DocumentNameChangeCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.ADDENDA + "/" + COMMANDNAME);
        AddendaEditor addendaEditor = editSession.getFichothequeEditor().getAddendaEditor(document.getAddenda().getSubsetKey());
        try {
            addendaEditor.setBasename(document, newDocumentName);
        } catch (ExistingNameException | ParseException pe) {
            throw new ShouldNotOccurException("test done before");
        }
        putResultObject(ADDENDA_OBJ, document.getAddenda());
        putResultObject(DOCUMENT_OBJ, document);
        setDone("_ done.addenda.documentnamechange");
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        document = BdfInstructionUtils.getMandatoryDocument(fichotheque, requestMap);
        PermissionChecker.init(bdfServer, bdfUser)
                .checkWrite(document);
        newDocumentName = getMandatory(NAME_PARAMNAME);
        newDocumentName = StringUtils.cleanString(newDocumentName);
        if (newDocumentName.length() == 0) {
            setError("_ error.empty.documentname", newDocumentName);
            return false;
        }
        if (!AddendaUtils.testBasename(newDocumentName)) {
            setError("_ error.wrong.documentname", newDocumentName);
            return false;
        }
        if (document.getAddenda().getDocumentByBasename(newDocumentName) != null) {
            setError("_ error.existing.documentname", newDocumentName);
            return false;
        }
        return true;
    }

}
