/* BdfServer_Commands - Copyright (c) 2015-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.exportation;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionConstants;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.api.interaction.InteractionConstants;
import fr.exemole.bdfserver.tools.exportation.transformation.BdfTransformationUtils;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import java.io.IOException;
import java.io.InputStream;
import net.fichotheque.EditOrigin;
import net.fichotheque.exportation.transformation.TemplateDescription;
import net.fichotheque.exportation.transformation.TemplateKey;
import net.fichotheque.extraction.def.ExtractionDef;
import net.fichotheque.xml.ExtractionDefXMLPart;
import net.mapeadores.util.io.IOUtils;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class TemplateExtractionReinitCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "TemplateExtractionReinit";
    private TemplateKey templateKey;
    private ExtractionDef extractionDef;

    public TemplateExtractionReinitCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() {
        EditOrigin editOrigin = bdfUser.newEditOrigin(Domains.EXPORTATION + "/" + COMMANDNAME);
        String extractionContent = ExtractionDefXMLPart.toString(extractionDef, true, false);
        try (InputStream is = IOUtils.toInputStream(extractionContent, "UTF-8")) {
            TemplateDescription templateDescription = bdfServer.getTransformationManager().putTemplateContent(templateKey, "extraction.xml", is, editOrigin);
            if (templateDescription != null) {
                putResultObject(BdfInstructionConstants.TEMPLATEDESCRIPTION_OBJ, templateDescription);
                setDone("_ done.exportation.templatecontentchange", templateKey.toString(), "extraction.xml");
            }
        } catch (IOException ioe) {
            setError("_ error.exception.templatecontent_io", ioe.getMessage());
        }
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        BdfInstructionUtils.checkGlobalAdminPermission(bdfServer, bdfUser);
        TemplateDescription templateDescription = BdfInstructionUtils.getMandatoryTemplateDescription(bdfServer, requestMap);
        this.templateKey = templateDescription.getTemplateKey();
        this.extractionDef = BdfTransformationUtils.getDefaultExtractionDef(bdfServer, templateKey.getTransformationKey());
        if (extractionDef == null) {
            throw new BdfInstructionException(BdfInstructionUtils.unsupportedNotEditableParameterValue(InteractionConstants.TEMPLATE_PARAMNAME, templateKey.toString() + "/extraction.xml"));
        }
        return true;
    }

}
