/* BdfServer_HtmlProducers - Copyright (c) 2010-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.album;

import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.api.interaction.domains.AlbumDomain;
import fr.exemole.bdfserver.html.BdfHtmlConstants;
import fr.exemole.bdfserver.html.consumers.Button;
import fr.exemole.bdfserver.tools.BH;
import fr.exemole.bdfserver.tools.BdfHref;
import net.fichotheque.album.Album;
import net.fichotheque.album.AlbumConstants;
import net.fichotheque.album.Illustration;
import net.fichotheque.album.metadata.AlbumMetadata;
import net.fichotheque.utils.AlbumUtils;
import net.mapeadores.util.awt.ResizeInfo;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.HtmlPrinter;
import net.mapeadores.util.html.TrustedHtml;
import net.mapeadores.util.html.TrustedHtmlFactory;


/**
 *
 * @author Vincent Calame
 */
public final class AlbumHtmlUtils {

    private AlbumHtmlUtils() {
    }

    public static TrustedHtml getThumbnailSize(AlbumMetadata albumMetadata) {
        ResizeInfo resizeInfo = albumMetadata.getResizeInfo(AlbumConstants.MINI_SPECIALDIM);
        StringBuilder buf = new StringBuilder();
        buf.append(".album-Thumbnail {");
        int width = resizeInfo.getWidth();
        if (width > 0) {
            buf.append("width: ");
            buf.append(width);
            buf.append("px;");
        }
        int height = resizeInfo.getHeight();
        if (height > 0) {
            buf.append("height: ");
            buf.append(height);
            buf.append("px;");
        }
        buf.append('}');
        return TrustedHtmlFactory.UNCHECK.build(buf.toString());
    }

    public static boolean printAlbumToolbar(HtmlPrinter hp, String pageActu, Album album) {
        hp
                .NAV("subset-Toolbar")
                .DIV("subset-Buttons")
                .SPAN("subset-SmallLabel")
                .__localize("_ title.global.commands")
                .__colon()
                ._SPAN()
                .__(printLink(hp, "action-Metadata", album, AlbumDomain.ALBUM_METADATAFORM_PAGE, "_ link.album.albummetadataform", pageActu))
                .__(printLink(hp, "action-Advanced", album, AlbumDomain.ALBUM_ADVANCEDCOMMANDS_PAGE, "_ link.album.albumadvancedcommands", pageActu))
                .__(printRefresh(hp, album))
                ._DIV()
                ._NAV();
        return true;
    }

    public static boolean printIllustrationToolbar(HtmlPrinter hp, String pageActu, Illustration illustration, boolean isSubsetAdmin) {
        hp
                .HEADER("subset-ItemHeader album-IllustrationHeader")
                .DIV("album-IllustrationThumbnail")
                .A(HA.href("illustrations/" + AlbumUtils.toFileName(illustration)))
                .IMG(HA.src("illustrations/_mini/" + AlbumUtils.toFileName(illustration)))
                ._A()
                ._DIV()
                .H1()
                .__escape(AlbumUtils.toFileName(illustration))
                ._H1()
                ._HEADER();
        hp
                .NAV("subset-Toolbar")
                .DIV("subset-Buttons")
                .SPAN("subset-SmallLabel")
                .__localize("_ title.global.commands")
                .__colon()
                ._SPAN()
                .__(printLink(hp, "action-IllustrationEdit", illustration, AlbumDomain.ILLUSTRATION_ADMINFORM_PAGE, "_ link.album.illustrationadminform", pageActu))
                .__(printLink(hp, "action-Advanced", illustration, AlbumDomain.ILLUSTRATION_ADVANCEDCOMMANDS_PAGE, "_ link.album.illustrationadvancedcommands", pageActu))
                .__(printRefresh(hp, illustration.getAlbum()))
                ._DIV()
                ._NAV();
        return true;
    }

    public static String getAlbumDimMessageKey(String dimType) {
        switch (dimType) {
            case AlbumConstants.FIXEDWIDTH_DIMTYPE:
                return "_ label.album.albumdimtype_fixedwidth";
            case AlbumConstants.FIXEDHEIGHT_DIMTYPE:
                return "_ label.album.albumdimtype_fixedheight";
            case AlbumConstants.MAXWIDTH_DIMTYPE:
                return "_ label.album.albumdimtype_maxwidth";
            case AlbumConstants.MAXHEIGHT_DIMTYPE:
                return "_ label.album.albumdimtype_maxheight";
            case AlbumConstants.MAXDIM_DIMTYPE:
                return "_ label.album.albumdimtype_maxdim";
            default:
                throw new IllegalArgumentException("unknown type " + dimType);
        }
    }

    private static boolean printLink(HtmlPrinter hp, String action, Object object, String page, String titleLocKey, String currentPage) {
        if (page.equals(currentPage)) {
            hp
                    .SPAN("global-button-Transparent global-button-Current " + action)
                    .__(Button.ICON)
                    ._SPAN();
        } else {
            BdfHref href = BH.domain(Domains.ALBUM).page(page);
            if (object instanceof Album) {
                href.subset((Album) object);
            } else if (object instanceof Illustration) {
                href.subsetItem((Illustration) object);
            }
            hp
                    .A(HA.href(href).titleLocKey(titleLocKey).classes("global-button-Transparent " + action))
                    .__(Button.ICON)
                    ._A();
        }
        return true;
    }

    private static boolean printRefresh(HtmlPrinter hp, Album album) {
        hp
                .A(HA
                        .href(BH.domain(Domains.ALBUM).page(AlbumDomain.ALBUM_PAGE).subset(album)).titleLocKey("_ link.global.reload")
                        .classes("global-button-Transparent action-Refresh")
                        .target(BdfHtmlConstants.LIST_FRAME))
                .__(Button.ICON)
                ._A();
        return true;
    }

}
