/* BdfServer_HtmlProducers - Copyright (c) 2010-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.configuration;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.ProducerParameters;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.api.interaction.InteractionConstants;
import fr.exemole.bdfserver.api.interaction.domains.ConfigurationDomain;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.commands.administration.ResourceUploadCommand;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.consumers.Grid;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import fr.exemole.bdfserver.tools.storage.StorageUtils;
import net.mapeadores.util.html.CommandBox;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.HtmlAttributes;


/**
 *
 * @author Vincent Calame
 */
public class LogosFormHtmlProducer extends BdfServerHtmlProducer {

    public LogosFormHtmlProducer(ProducerParameters producerParameters) {
        this(producerParameters.getBdfServer(), producerParameters.getBdfUser());
    }

    public LogosFormHtmlProducer(BdfServer bdfServer, BdfUser bdfUser) {
        super(bdfServer, bdfUser);
    }

    @Override
    public void printHtml() {
        boolean contains = StorageUtils.containsVarResource(bdfServer, StorageUtils.ICON);
        boolean contains32 = StorageUtils.containsVarResource(bdfServer, StorageUtils.ICON32);
        boolean containsLogo = StorageUtils.containsResource(bdfServer, StorageUtils.LOGO);
        start();
        printCommandMessageUnit();
        CommandBox commandBox = CommandBox.init()
                .action(Domains.CONFIGURATION)
                .family("CNF")
                .page(ConfigurationDomain.LOGOSFORM_PAGE)
                .name(BdfInstructionUtils.getAbsoluteCommandName(Domains.ADMINISTRATION, ResourceUploadCommand.COMMANDNAME))
                .multipart(true)
                .lockey(ResourceUploadCommand.ICON16_COMMANDKEY)
                .hidden(InteractionConstants.PATH_PARAMNAME, StorageUtils.ICON.toString())
                .submitLocKey("_ submit.administration.resourceupload");
        this
                .__start(commandBox)
                .__(Grid.START)
                .__(printImageRow(contains, HA.src("images/icon.png").alt("icon 16x16").height("16").width("16")))
                .__(printFileInput("_ label.configuration.file_icon"))
                .__(Grid.END)
                .__end(commandBox);
        commandBox
                .lockey(ResourceUploadCommand.ICON32_COMMANDKEY)
                .hidden(InteractionConstants.PATH_PARAMNAME, StorageUtils.ICON32.toString());
        this
                .__start(commandBox)
                .__(Grid.START)
                .__(printImageRow(contains32, HA.src("images/icon32.png").alt("icon 32x32").height("32").width("32")))
                .__(printFileInput("_ label.configuration.file_icon"))
                .__(Grid.END)
                .__end(commandBox);
        commandBox
                .lockey(ResourceUploadCommand.LOGO_COMMANDKEY)
                .hidden(InteractionConstants.PATH_PARAMNAME, StorageUtils.LOGO.toString());
        this
                .__start(commandBox)
                .__(Grid.START)
                .__(printLogoRow(containsLogo, HA.src("images/logo.png").alt("logo")))
                .__(printFileInput("_ label.configuration.file_logo"))
                .__(Grid.END)
                .__end(commandBox);
        end();
    }

    private boolean printImageRow(boolean contains, HtmlAttributes imgAttributes) {
        String locKey = (contains) ? "_ label.configuration.icon_current" : "_ label.configuration.icon_default";
        this
                .P("grid-Row")
                .__(Grid.printLabelCells(this, locKey))
                .SPAN("grid-InputCell")
                .IMG(imgAttributes)
                ._SPAN()
                ._P();
        return true;
    }

    private boolean printLogoRow(boolean contains, HtmlAttributes imgAttributes) {
        if (contains) {
            this
                    .P("grid-Row")
                    .__(Grid.printLabelCells(this, "_ label.configuration.logo_current"))
                    .SPAN("grid-InputCell")
                    .IMG(imgAttributes)
                    ._SPAN()
                    ._P();
        } else {
            this
                    .P("grid-Row")
                    .SPAN("grid-UniqueCell")
                    .__localize("_ info.configuration.nologo")
                    ._SPAN()
                    ._P();
        }
        return true;
    }

    private boolean printFileInput(String messageKey) {
        this
                .__(Grid.fileInputRow(messageKey, name(ResourceUploadCommand.FILE_PARAMNAME).size("75").classes("global-FileInput")));
        return true;
    }

}
