/* BdfServer_JsonProducers - Copyright (c) 2017-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.jsonproducers.session;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfCommandResult;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.instruction.OutputParameters;
import fr.exemole.bdfserver.api.interaction.domains.SessionDomain;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.mapeadores.util.json.JsonProducer;
import net.mapeadores.util.localisation.LangPreference;
import net.mapeadores.util.localisation.MessageLocalisation;
import net.mapeadores.util.logging.CommandMessage;


/**
 *
 * @author Vincent Calame
 */
public final class SessionJsonProducerFactory {

    private SessionJsonProducerFactory() {

    }

    public static JsonProducer getJsonProducer(OutputParameters parameters) throws BdfInstructionException {
        String json = parameters.getOutput();
        switch (json) {
            case SessionDomain.PING_JSON: {
                BdfServer bdfServer = parameters.getBdfServer();
                BdfUser bdfUser = parameters.getBdfUser();
                LangPreference langPreference;
                if (bdfUser == null) {
                    langPreference = BdfInstructionUtils.getLangPreference(parameters.getRequestMap(), bdfServer);
                } else {
                    langPreference = bdfUser.getLangPreference();
                }
                MessageLocalisation messageLocalisation = bdfServer.getL10nManager().getMessageLocalisation(langPreference);
                BdfCommandResult bdfCommandResult = parameters.getBdfCommandResult();
                CommandMessage commandMessage = null;
                if (bdfCommandResult != null) {
                    commandMessage = bdfCommandResult.getCommandMessage();
                }
                if (bdfUser == null) {
                    return PingJsonProducer.unauthentified(messageLocalisation, commandMessage);
                } else {
                    return PingJsonProducer.authentified(bdfServer, bdfUser, messageLocalisation, commandMessage);
                }
            }
            default:
                return null;
        }
    }

}
