/* BdfServer_JsonProducers - Copyright (c) 2017-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.jsonproducers.thesaurus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfCommandResult;
import fr.exemole.bdfserver.api.instruction.BdfInstructionConstants;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.instruction.OutputParameters;
import fr.exemole.bdfserver.api.interaction.domains.ThesaurusDomain;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.jsonproducers.ResultJsonProducer;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import fr.exemole.bdfserver.tools.instruction.PermissionChecker;
import net.fichotheque.thesaurus.Thesaurus;
import net.fichotheque.utils.ThesaurusUtils;
import net.mapeadores.util.json.JsonProducer;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.MessageLocalisation;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public final class ThesaurusJsonProducerFactory {

    private ThesaurusJsonProducerFactory() {

    }

    public static JsonProducer getJsonProducer(OutputParameters parameters) throws BdfInstructionException {
        String json = parameters.getOutput();
        BdfServer bdfServer = parameters.getBdfServer();
        BdfUser bdfUser = parameters.getBdfUser();
        BdfCommandResult bdfCommandResult = parameters.getBdfCommandResult();
        RequestMap requestMap = parameters.getRequestMap();
        Lang lang = bdfUser.getWorkingLang();
        MessageLocalisation messageLocalisation = bdfServer.getL10nManager().getMessageLocalisation(bdfUser.getLangPreference());
        ResultJsonProducer jsonProducer = new ResultJsonProducer(bdfCommandResult, messageLocalisation);
        Thesaurus thesaurus = getThesaurus(bdfServer, requestMap, bdfCommandResult);
        PermissionChecker checker = new PermissionChecker(bdfServer, bdfUser);
        checker.checkSubsetAccess(thesaurus);
        switch (json) {
            case ThesaurusDomain.THESAURUS_JSON: {
                lang = ThesaurusUtils.checkDisponibility(bdfServer.getThesaurusLangChecker(), thesaurus, lang);
                jsonProducer.add(new ThesaurusJsonProperty(thesaurus, lang, BdfInstructionUtils.getCellEngine(bdfServer, bdfUser, checker.getPermissionSummary(), requestMap)));
                return jsonProducer;
            }
            case ThesaurusDomain.THESAURUS_METADATA_JSON: {
                jsonProducer.add(new ThesaurusMetadataJsonProperty(thesaurus.getThesaurusMetadata()));
                return jsonProducer;
            }
            default:
                return null;
        }
    }

    private static Thesaurus getThesaurus(BdfServer bdfServer, RequestMap requestMap, BdfCommandResult bdfCommandResult) throws BdfInstructionException {
        Thesaurus thesaurus = null;
        if (bdfCommandResult != null) {
            thesaurus = (Thesaurus) bdfCommandResult.getResultObject(BdfInstructionConstants.THESAURUS_OBJ);
        }
        if (thesaurus == null) {
            thesaurus = BdfInstructionUtils.getMandatoryThesaurus(bdfServer.getFichotheque(), requestMap);
        }
        return thesaurus;
    }

}
