/* global BDF,$$ */
/**
 * Objet global définissant l'espace de nom Memento
 * 
 * @namespace Memento
 */
var Memento = {};

Memento.init = function (mementoUnitInfoArray) {
    var localStorage = BDF.getMainLocalStorage();
    if (!localStorage) {
        localStorage = new Object();
    }
    var unitMap = {};
    var $body = $("body");
    for(let mementoUnit of mementoUnitInfoArray) {
        let path = mementoUnit.path;
        if (!localStorage.hasOwnProperty(path)) {
            let newObject = new Object();
            newObject.nodes = {};
            newObject.open = false;
            localStorage[path] = newObject;
            mementoUnit.localStorage  = newObject;
        } else {
            let unitLocalStorage = localStorage[path];
            if (!unitLocalStorage.nodes) {
                unitLocalStorage.nodes = {};
            }
            mementoUnit.open = unitLocalStorage.open;
            mementoUnit.localStorage = unitLocalStorage;
        }
        mementoUnit.subnodeArray = false;
        mementoUnit.onLoad = false;
        unitMap[path] = mementoUnit;
    }
    $body.append(BDF.render("memento:unit", {mementoUnitInfoArray: mementoUnitInfoArray}));
    for(let mementoUnit of mementoUnitInfoArray) {
        if (mementoUnit.open) {
            _loadSubnodeArray(mementoUnit, BDF.$($body, {role:"unit", path: mementoUnit.path}));
        }
    }
    BDF.$($body, {role:"unit"}).on("toggle", function () {
        let $unit = $(this);
        let path = $unit.data("path");
        let unit = unitMap[path];
        if (!unit.subnodeArray) {
            _loadSubnodeArray(unit, $unit);
        }
        localStorage[path].open = this.open;
        BDF.putMainLocalStorage(localStorage);
    });
    
    
    function _loadSubnodeArray(unit, $unit) {
        if (unit.onLoad) {
            return;
        }
        unit.onLoad = true;
        BDF.Ajax.loadMementoUnit(unit.path, function (mementoUnit) {
            unit.subnodeArray = mementoUnit.subnodeArray;
            __completeNodes(unit.subnodeArray);
            BDF.$($unit, {role:"tree"}).html(BDF.render("memento:node", unit.subnodeArray));
            BDF.$($unit, {_element:"details"}).on("toggle", function () {
                unit.localStorage.nodes[$(this).data("name")] = this.open;
                BDF.putMainLocalStorage(localStorage);
            });
        });
        
        
        function __completeNodes(nodeArray) {
            for(let node of nodeArray) {
                node.generatedId = BDF.generateId();
                if (!node.leaf) {
                    __completeNodes(node.subnodeArray);
                }
                let open = false;
                if (unit.localStorage.nodes.hasOwnProperty(node.name)) {
                    if (unit.localStorage.nodes[node.name]) {
                        open = true;
                    }
                }
                node.open = open;
            }
        }

    }

};


/******************************************************************************/

$(function () {
    BDF.initTemplates();
    BDF.Ajax.loadMementoUnitInfoArray(function (mementoUnitInfoArray) {
        Memento.init(mementoUnitInfoArray);
    });
});