/* FichothequeLib_API - Copyright (c) 2006-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.utils;

import net.fichotheque.Fichotheque;
import net.fichotheque.FichothequeConstants;
import net.fichotheque.metadata.FichothequeMetadata;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.text.Label;
import net.mapeadores.util.text.LabelUtils;
import net.mapeadores.util.text.Phrase;


/**
 *
 * @author Vincent Calame
 */
public final class FichothequeMetadataUtils {

    private FichothequeMetadataUtils() {
    }

    public static String getTitle(Fichotheque fichotheque, Lang lang) {
        return FichothequeMetadataUtils.getTitle(fichotheque.getFichothequeMetadata(), lang);
    }

    public static String getTitle(FichothequeMetadata fichothequeMetadata, Lang lang) {
        Label label = LabelUtils.getLangPartCheckedLabel(fichothequeMetadata.getTitleLabels(), lang);
        if (label != null) {
            return label.getLabelString();
        } else {
            return fichothequeMetadata.getBaseName();
        }
    }

    public static String getLongTitle(Fichotheque fichotheque, Lang lang) {
        return phraseToString(fichotheque.getFichothequeMetadata(), FichothequeConstants.LONG, lang);
    }

    private static String phraseToString(FichothequeMetadata fichothequeMetadata, String name, Lang lang) {
        Phrase fichothequePhrase = fichothequeMetadata.getPhrases().getPhrase(name);
        if (fichothequePhrase != null) {
            Label label = LabelUtils.getLangPartCheckedLabel(fichothequePhrase, lang);
            if (label != null) {
                return label.getLabelString();
            }
        }
        return fichothequeMetadata.getBaseName();
    }

}
