/* FichothequeLib_Tools - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction.builders;

import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import net.fichotheque.SubsetKey;
import net.fichotheque.extraction.ExtractionConstants;
import net.fichotheque.extraction.def.FicheFilter;
import net.fichotheque.extraction.def.FicheRattachementDef;
import net.fichotheque.utils.FichothequeUtils;


/**
 *
 * @author Vincent Calame
 */
public class FicheRattachementDefBuilder implements ExtractionConstants {

    private final Set<SubsetKey> subsetKeySet = new LinkedHashSet<SubsetKey>();
    private FicheFilter ficheFilter;

    public FicheRattachementDefBuilder(FicheFilter ficheFilter) {
        if (ficheFilter == null) {
            throw new IllegalArgumentException("ficheFilter is null");
        }
        this.ficheFilter = ficheFilter;
    }

    public FicheRattachementDefBuilder setFicheFilter(FicheFilter ficheFilter) {
        if (ficheFilter == null) {
            throw new IllegalArgumentException("ficheFilter is null");
        }
        this.ficheFilter = ficheFilter;
        return this;
    }

    public FicheRattachementDefBuilder addRattachementSubsetKey(SubsetKey subsetKey) {
        if (!subsetKey.isCorpusSubset()) {
            throw new IllegalArgumentException();
        }
        subsetKeySet.add(subsetKey);
        return this;
    }

    public FicheRattachementDef toFicheRattachementDef() {
        List<SubsetKey> list;
        if (!subsetKeySet.isEmpty()) {
            list = FichothequeUtils.wrap(subsetKeySet.toArray(new SubsetKey[subsetKeySet.size()]));
        } else {
            list = FichothequeUtils.EMPTY_SUBSETKEYLIST;
        }
        return new InternalFicheRattachementDef(ficheFilter, list);
    }

    public static FicheRattachementDefBuilder init(FicheFilter ficheFilter) {
        return new FicheRattachementDefBuilder(ficheFilter);
    }


    private static class InternalFicheRattachementDef implements FicheRattachementDef {

        private final FicheFilter ficheFilter;
        private final List<SubsetKey> subsetKeyList;

        private InternalFicheRattachementDef(FicheFilter ficheFilter, List<SubsetKey> subsetKeyList) {
            this.ficheFilter = ficheFilter;
            this.subsetKeyList = subsetKeyList;
        }

        @Override
        public FicheFilter getFicheFilter() {
            return ficheFilter;
        }

        @Override
        public List<SubsetKey> getRattachementSubsetKeyList() {
            return subsetKeyList;
        }

    }

}
