/* FichothequeLib_Tools - Copyright (c) 2013-2019 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.format.tokenizers.subfield;

import net.fichotheque.corpus.SubfieldValue;
import net.fichotheque.corpus.fiche.FicheItem;
import net.fichotheque.corpus.fiche.Montant;
import net.fichotheque.corpus.metadata.SubfieldKey;
import net.fichotheque.format.FormatSource;
import net.fichotheque.format.Tokens;
import net.fichotheque.format.formatters.SubfieldFormatter;
import net.fichotheque.pointeurs.FichePointeur;
import net.fichotheque.utils.FormatterUtils;
import net.mapeadores.util.exceptions.SwitchException;
import net.fichotheque.format.Tokenizer;


/**
 *
 * @author Vincent Calame
 */
class MontantProprieteTokenizer implements Tokenizer {

    private final SubfieldKey subfieldKey;
    private final SubfieldFormatter subfieldFormatter;

    MontantProprieteTokenizer(SubfieldKey subfieldKey, SubfieldFormatter subfieldFormatter) {
        this.subfieldKey = subfieldKey;
        this.subfieldFormatter = subfieldFormatter;
    }

    @Override
    public Tokens tokenize(FormatSource formatSource) {
        FicheItem ficheItem = (FicheItem) ((FichePointeur) formatSource.getSubsetItemPointeur()).getValue(subfieldKey.getFieldKey());
        if ((ficheItem == null) || (!(ficheItem instanceof Montant))) {
            return FormatterUtils.EMPTY_TOKENS;
        }
        Montant montant = (Montant) ficheItem;
        short subfieldType = subfieldKey.getSubtype();
        String sourceValue;
        if (subfieldType == SubfieldKey.CURRENCY_SUBTYPE) {
            sourceValue = montant.getCurrency().getCurrencyCode();
        } else if (subfieldType == SubfieldKey.VALUE_SUBTYPE) {
            sourceValue = montant.getDecimal().toString();
        } else {
            throw new SwitchException("subfieldType = " + subfieldType);
        }
        SubfieldValue subfieldValue = FormatterUtils.toSubfieldValue(sourceValue);
        String value = subfieldFormatter.formatSubfield(subfieldValue, formatSource);
        return FormatterUtils.toTokens(value);
    }

}
