/* FichothequeLib_Tools - Copyright (c) 2007-2014 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.parsers;

import java.text.ParseException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import net.fichotheque.corpus.fiche.Atts;


/**
 *
 * @author Vincent Calame
 */
public class LineInfo {

    public final static List<Atts> EMPTY_ATTSLIST = Collections.emptyList();
    private final List<Atts> attsList;
    private final String cleanedLine;
    private final boolean attsError;

    private LineInfo(String line, List<Atts> attsList, boolean attsError) {
        this.cleanedLine = line;
        this.attsList = attsList;
        this.attsError = attsError;
    }

    public boolean isCleanedLineEmpty() {
        return (cleanedLine.length() == 0);
    }

    public List<Atts> getAttsList() {
        return attsList;
    }

    public String getCleanedLine() {
        return cleanedLine;
    }

    public boolean hasAttsError() {
        return attsError;
    }

    public LineInfo deriveWithoutAttsList() {
        if ((attsList.isEmpty()) && (!attsError)) {
            return this;
        }
        return new LineInfo(cleanedLine, EMPTY_ATTSLIST, false);
    }

    public static LineInfo parse(String line) {
        if (line.length() == 0) {
            return new LineInfo("", EMPTY_ATTSLIST, false);
        }
        if (!line.startsWith("[(")) {
            return new LineInfo(line, EMPTY_ATTSLIST, false);
        }
        try {
            return parseWithAttsList(line);
        } catch (ParseException pe) {
            return new LineInfo(line, EMPTY_ATTSLIST, true);
        }
    }

    private static LineInfo parseWithAttsList(String line) throws ParseException {
        List<Atts> attsList = new ArrayList<Atts>();
        int startIndex = 2;
        int closeIndex = -1;
        while (true) {
            AttsParser parser = new AttsParser(line, startIndex);
            parser.run();
            closeIndex = parser.getCloseIndex();
            if (closeIndex == (line.length() - 1)) {
                throw new ParseException("Missing closing ]", closeIndex);
            }
            attsList.add(parser.getAtts());
            char nextChar = line.charAt(closeIndex + 1);
            if (nextChar == ']') {
                break;
            } else if (nextChar == '(') {
                startIndex = closeIndex + 2;
            } else {
                throw new ParseException("Missing ] or (", closeIndex + 1);
            }
        }
        String newLine;
        if ((line.length() > (closeIndex + 2)) && (line.charAt(closeIndex + 2) == ' ')) {
            newLine = line.substring(closeIndex + 3);
        } else {
            newLine = line.substring(closeIndex + 2);
        }
        return new LineInfo(newLine, attsList, false);
    }

}
