/* FichothequeLib_Tools - Copyright (c) 2015-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.parsers.croisement;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;
import net.fichotheque.SubsetKey;


/**
 *
 * @author Vincent Calame
 */
public class SubtokenParameters {

    private final List<SubtokenParameter> documentFileList = new ArrayList<SubtokenParameter>();
    private final List<SubtokenParameter> documentList = new ArrayList<SubtokenParameter>();
    private final List<SubtokenParameter> illustrationFileList = new ArrayList<SubtokenParameter>();
    private final List<SubtokenParameter> illustrationList = new ArrayList<SubtokenParameter>();

    private SubtokenParameters() {

    }

    public List<SubtokenParameter> getDocumentFileList() {
        return documentFileList;
    }

    public List<SubtokenParameter> getDocumentList() {
        return documentList;
    }

    public List<SubtokenParameter> getIllustrationFileList() {
        return illustrationFileList;
    }

    public List<SubtokenParameter> getIllustrationList() {
        return illustrationList;
    }

    public boolean withIllustration() {
        return (!illustrationFileList.isEmpty()) || (!illustrationList.isEmpty());
    }

    public boolean withDocument() {
        return (!documentFileList.isEmpty()) || (!documentList.isEmpty());
    }

    public static SubtokenParameters build(Set<String> paramNameSet) {
        SubtokenParameters subtokenParameters = new SubtokenParameters();
        for (String paramName : paramNameSet) {
            SubtokenParameter subtokenParameter = SubtokenParameter.check(paramName);
            if (subtokenParameter != null) {
                short category = subtokenParameter.getIncludeKey().getSubsetKey().getCategory();
                if (category == SubsetKey.CATEGORY_ALBUM) {
                    if (subtokenParameter.getSubname().equals("file")) {
                        subtokenParameters.illustrationFileList.add(subtokenParameter);
                    } else {
                        subtokenParameters.illustrationList.add(subtokenParameter);
                    }
                } else if (category == SubsetKey.CATEGORY_ADDENDA) {
                    if (subtokenParameter.getSubname().equals("file")) {
                        subtokenParameters.documentFileList.add(subtokenParameter);
                    } else {
                        subtokenParameters.documentList.add(subtokenParameter);
                    }
                }
            }
        }
        return subtokenParameters;
    }

}
